@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 4061 2011-04-08 08:46:26Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 4190 2011-06-13 10:42:57Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -26,6 +26,10 @@ class ScriptLibInfo
 	const LIB_MD5					= 'md5';
 	const LIB_SWFOBJECT				= 'swfobject';
 	
+	// スマートフォン用jQueryライブラリ
+	const LIB_JQUERYS				= 'jquerys';
+	const LIB_JQUERYS_MOBILE		= 'jquery.mobile';
+		
 	// jQueryプラグイン
 	const LIB_JQUERY_EASING			= 'jquery.easing';
 	const LIB_JQUERY_JCAROUSEL		= 'jquery.jcarousel';
@@ -140,6 +144,11 @@ class ScriptLibInfo
 	const JQUERY_UI_WIDGETS_TABS_FILENAME			= 'jquery/ui/1.8.2/jquery.ui.tabs.min.js';				// Widgets Tabs
 	const JQUERY_UI_EFFECTS_FILENAME				= 'jquery/ui/1.8.2/jquery.effects.min.js';					// Effects
 	
+	// スマートフォン用jQueryファイル
+	const JQUERYS_FILENAME			= 'jquery-1.5.2.min.js';					// JQuery
+	const JQUERYS_MOBILE_FILENAME	= 'jquery_mobile/jquery.mobile-1.0a4.1.min.js';					// JQuery Mobile
+	const JQUERYS_MOBILE_CSS		= 'jquery_mobile/jquery.mobile-1.0a4.1.min.css';				// JQuery Mobile
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -158,7 +167,7 @@ class ScriptLibInfo
 	/**
 	 * jQueryファイル名取得
 	 *
-	 * @param  int    $type	ファイルの種別(0=jQuery、1=jQuery UI Core、2=jQuery UI Plus)
+	 * @param  int    $type	ファイルの種別(0=jQuery、1=jQuery UI Core、2=jQuery UI Plus、10=スマートフォン用jQuery)
 	 * @return string		jQueryファイル名を取得
 	 */
 	static function getJQueryFilename($type = 0)
@@ -191,6 +200,8 @@ class ScriptLibInfo
 					$filename = self::JQUERY_L_UI_PLUS_FILENAME;	// jquery UI
 					break;
 			}
+		} else if ($type == 10){	// スマートフォン用jQuery
+			$filename = self::JQUERYS_FILENAME;
 		}
 		return $filename;
 	}
@@ -272,6 +283,12 @@ class ScriptLibInfo
 				$libs[self::LIB_JQUERY_UI_EFFECTS]				= array(	'script' => array(self::JQUERY_UI_EFFECTS_FILENAME));				// Effects
 				break;
 		}
+		
+		// スマートフォン用jQueryライブラリ
+		$libs[self::LIB_JQUERYS] 			= array(	'script' => array(self::getJQueryFilename(10)));		// スマートフォン用jQuery
+		$libs[self::LIB_JQUERYS_MOBILE]		= array(	'script' 	=> array(self::JQUERYS_MOBILE_FILENAME),	// JQuery Mobile
+														'css'		=> array(self::JQUERYS_MOBILE_CSS));
+														
 		return $libs;
 	}
 	/**
