@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 4186 2011-06-12 08:49:00Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 4224 2011-07-11 09:47:25Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -468,7 +468,7 @@ class BaseWidgetContainer extends Core
 				$msg = $this->_g('You must enter %s.');			// メッセージを取得「%sが入力されていません」
 				array_push($this->warningMessage, sprintf($msg, $title));
 			} else {		// エラーメッセージが設定されている場合
-				array_push($this->warningMessage, $errorMsg);
+				array_push($this->warningMessage,  sprintf($errorMsg, $title));// 「%s」がある場合は項目名を設定
 			}
 			return false;
 		}
