@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 4210 2011-06-16 05:41:44Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 4230 2011-07-19 03:35:44Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -22,7 +22,7 @@
 INSERT INTO _system_config 
 (sc_id,                          sc_value,                  sc_name) VALUES
 ('system_name',                 'Magic3',                   'システム名称'),
-('db_version',                  '2011061601',               'DBバージョン'),
+('db_version',                  '2011070101',               'DBバージョン'),
 ('server_id',                   '',                         'サーバ識別用ID'),
 ('server_url',                  '',                         'サーバURL'),
 ('default_lang',                'ja',                       'デフォルト言語'),
@@ -71,6 +71,9 @@ INSERT INTO _system_config
 ('page_cache_lifetime',          '1440',                    '画面キャッシュの保持時間(分)'),
 ('use_connect_server',           '1',                       'ポータルサーバ接続'),
 ('default_connect_server_url',   '',                        'デフォルトの連携サーバURL'),
+('portal_server_version',        '',                        'ポータルサーババージョン'),
+('portal_server_url',            'http://magic3.me',        'ポータルサーバURL'),
+('site_registered_in_portal',    '0',                       'ポータルサーバへのサイトの登録状況'),
 ('config_window_open_type',      '0',                       '設定画面のウィンドウ表示タイプ'),
 ('config_window_style',          'toolbar=no,menubar=no,location=no,status=no,scrollbars=yes,resizable=yes,width=1050,height=900',               '設定画面の表示属性'),
 ('dev_use_latest_script_lib',    '0',                       '最新JavaScriptライブラリの使用(開発用)'),
