@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_std.sql 4125 2011-05-09 05:55:32Z fishbone $
+-- * @version    SVN: $Id: insert_std.sql 4207 2011-06-16 03:09:17Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -176,7 +176,9 @@ INSERT INTO _templates
 ('art30rc1_sample1',              'art30rc1_sample1',              1,       0,              false,     true,         0,             now()),
 ('m/default',                     'm/default',                     0,       1,              true,      true,         0,             now()),
 ('m/smallfont',                   'm/smallfont',                   0,       1,              true,      true,         0,             now()),
-('s/default',                     's/default',                     1,       2,              false,     true,         0,             now());
+('s/default_simple',              's/default_simple',              1,       2,              false,     true,         0,             now()),
+('s/default_jquery',              's/default_jquery',              1,       2,              false,     true,         0,             now()),
+('s/art_test',                    's/art_test',                    1,       2,              false,     true,         0,             now());
 
 -- メニューIDマスター
 INSERT INTO _menu_id
