@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetContainer.php 4140 2011-05-16 14:21:08Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetContainer.php 4223 2011-07-08 03:56:33Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -191,6 +191,8 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 					} else if ($task == 'pagehead' ||				// ページヘッダ情報
 								$task == 'pagehead_detail'){		// ページヘッダ情報
 						$task = 'pagehead';
+					} else if ($task == 'portal'){		// Magic3ポータル
+						$task = 'portal';
 					} else if ($task == 'tenantserver_detail'){		// テナントサーバ管理詳細
 						$task = 'tenantserver';
 					} else if ($task == 'analyzecalc'){		// アクセス解析集計
@@ -238,6 +240,7 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 						case 'smenudef':			// 単一階層メニュー定義
 						case 'configsite':			// サイト情報
 						case 'pagehead':			// ページヘッダ情報
+						case 'portal':				// Magic3ポータル
 						case 'tenantserver':			// テナントサーバ管理
 						case 'analyzecalc':		// アクセス解析集計
 						case 'analyzegraph':		// アクセス解析グラフ表示
