@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 4149 2011-05-23 14:05:10Z fishbone $
+ * @version    SVN: $Id: index.php 4152 2011-05-25 14:31:16Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -39,36 +39,6 @@ $HELP['configlang_value']['body'] = '識別用の値です。';
 $HELP['configlang_accept']['title'] = '許可';
 $HELP['configlang_accept']['body'] = 'アクセス可能な言語にチェックを入れます。';
 
-// ########## ユーザ一覧 ##########
-$HELP['userlist']['title'] = 'ユーザ一覧';
-$HELP['userlist']['body'] = 'システムで一元管理するユーザの一覧です。';
-$HELP['userlist_check']['title'] = '選択用チェックボックス';
-$HELP['userlist_check']['body'] = '編集や削除を行う項目を選択します。';
-$HELP['userlist_account']['title'] = 'ログインアカウント';
-$HELP['userlist_account']['body'] = 'ログイン時に使用するアカウントです。<br />メールアドレス形式のアカウントも使用できます。';
-$HELP['userlist_pwd']['title'] = 'パスワード';
-$HELP['userlist_pwd']['body'] = 'ログイン時に使用するパスワードです。';
-$HELP['userlist_name']['title'] = '名前';
-$HELP['userlist_name']['body'] = '画面上に表示されるユーザの名前です。';
-$HELP['userlist_usertype']['title'] = 'ユーザ種別';
-$HELP['userlist_usertype']['body'] = '管理者 - すべての管理機能が使用可能です。<br />運営者 - 制限された管理機能が使用可能です。<br />投稿者 - サイトにログインでき、ブログ等の記事の投稿が可能です。<br />一般 - サイトにログインできます。<br />仮登録 - 一般機能からユーザ登録を行い、まだログインしていないユーザです。一度ログインすると一般ユーザに変更されます。<br />未承認 - 承認を申請し、まだ承認されていないユーザです。';
-$HELP['userlist_admin']['title'] = '管理権限';
-$HELP['userlist_admin']['body'] = '管理機能(管理画面)が使用可能かどうかの設定です。<br />チェックが入っていると管理機能が使用可能です。';
-$HELP['userlist_login']['title'] = 'ログイン可';
-$HELP['userlist_login']['body'] = 'ログインを許可するかどうかの設定です。<br />チェックが入っているとログイン可能です。<br />誤操作防止のため、管理者はログイン不可にできません。';
-$HELP['userlist_login_count']['title'] = 'ログイン回数';
-$HELP['userlist_login_count']['body'] = 'ログインした回数です。';
-$HELP['userlist_active_term']['title'] = '有効期間';
-$HELP['userlist_active_term']['body'] = 'アカウントが有効な期間を設定します。空の場合は制限なしを示します。';
-$HELP['userlist_new_btn']['title'] = '新規ボタン';
-$HELP['userlist_new_btn']['body'] = '新規ユーザを追加します。';
-$HELP['userlist_edit_btn']['title'] = '編集ボタン';
-$HELP['userlist_edit_btn']['body'] = '選択されているユーザを編集します。<br />ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
-$HELP['userlist_del_btn']['title'] = '削除ボタン';
-$HELP['userlist_del_btn']['body'] = '選択されているユーザを削除します。<br />ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
-$HELP['userlist_ret_btn']['title'] = '戻るボタン';
-$HELP['userlist_ret_btn']['body'] = 'ユーザ一覧へ戻ります。';
-
 // ########## テーブルデータ編集 ##########
 $HELP['edittable_new_btn']['title'] = '新規ボタン';
 $HELP['edittable_new_btn']['body'] = '新規レコードを追加します。';
